@@ -4,6 +4,7 @@ import os,sys
 from rdflib import Namespace, Literal,RDFS
 from rdflib.namespace import XSD
 from rdflib.resource import Resource
+from rdflib.util import from_n3
 from urllib.parse import urlparse, urlsplit
 from rdflib import Graph, RDF, URIRef, util
 from rdflib.namespace import split_uri
@@ -19,6 +20,7 @@ import getpass
 from numpy import base_repr
 from binascii import crc32
 import pandas as pd
+from uuid import UUID
 
 #NIDM imports
 from ..core import Constants
@@ -388,7 +390,7 @@ def add_metadata_for_subject (rdf_graph,subject_uri,namespaces,nidm_obj):
                     # automatically by provDocument so they aren't accessible via the namespaces list
                     # so we check explicitly here
                     if ((obj_nm == str(Constants.PROV))):
-                        nidm_obj.add_attributes({predicate: Constants.PROV[obj_term]})
+                        nidm_obj.add_attributes({predicate: pm.QualifiedName(Constants.PROV,obj_term)})
                     elif ((obj_nm == str(Constants.NIDM))):
                         nidm_obj.add_attributes({predicate: pm.QualifiedName(Constants.NIDM,obj_term)})
                     else:
@@ -403,9 +405,12 @@ def add_metadata_for_subject (rdf_graph,subject_uri,namespaces,nidm_obj):
                 except:
                     nidm_obj.add_attributes({predicate: pm.QualifiedName(namespace=Namespace(str(objects)),localpart="")})
             else:
-
+                # check if this is a qname and if so expand it
+                # added to handle when a value is a qname.  this should expand it....
+                if (":" in objects) and isinstance(objects,URIRef):
+                    objects = from_n3(objects)
                 # check if objects is a url and if so store it as a URIRef else a Literal
-                if validators.url(objects):
+                if (validators.url(objects)):
                     obj_nm, obj_term = split_uri(objects)
                     nidm_obj.add_attributes({predicate : Identifier(objects)})
                 else:
@@ -909,7 +914,7 @@ def map_variables_to_terms(df,directory, assessment_name, output_file=None,json_
             # check if json_source is a file
             if os.path.isfile(json_source):
                 # load file
-                with open(json_source,'r+') as f:
+                with open(json_source,'r') as f:
                     json_map = json.load(f)
             else:
                 print("ERROR: Can't open json mapping file: %s" %(json_source))
@@ -1779,3 +1784,26 @@ def tupleKeysToSimpleKeys(dict):
 
 
     return new_dict
+
+
+
+def validate_uuid(uuid_string):
+
+    """
+    Validate that a UUID string is in
+    fact a valid uuid4.
+    Happily, the uuid module does the actual
+    checking for us.
+    It is vital that the 'version' kwarg be passed
+    to the UUID() call, otherwise any 32-character
+    hex string is considered valid.
+    """
+
+    try:
+        val = UUID(uuid_string)
+    except ValueError:
+        # If it's a value error, then the string
+        # is not a valid hex code for a UUID.
+        return False
+
+    return True
