@@ -5,6 +5,7 @@ from nidm.core import Constants
 import json
 import re
 from urllib import parse
+import logging
 import pprint
 import os
 from tempfile import gettempdir
@@ -12,7 +13,7 @@ from tabulate import tabulate
 from copy import copy, deepcopy
 from urllib.parse import urlparse, parse_qs
 from  nidm.experiment import Navigate
-
+from nidm.experiment.Utils import validate_uuid
 
 from numpy import std, mean, median
 import functools
@@ -242,9 +243,9 @@ class RestParser:
         if self.output_format == self.CLI_FORMAT:
 
             subjects = []
-            for sub in subject_data['uuid']:
-                subjects.append([sub])
-            text = tabulate(subjects, headers=["Subject UUID"])
+            for subject in subject_data['subject']:
+                subjects.append(subject)
+            text = tabulate(subjects, headers=["Subject UUID", "Source Subject ID"])
 
             if 'fields' in subject_data:
                 field_data = []
@@ -299,7 +300,7 @@ class RestParser:
                 if key in result:
                     if type(result[key]) == dict:
                         toptable.append( [ key, ",".join(result[key].keys()) ] )
-                    if type(result[key]) == list and type(result[key][0]) == Navigate.ActivityData:
+                    if type(result[key]) == list and len(result[key]) > 0 and  type(result[key][0]) == Navigate.ActivityData:
                         toptable.append( [ key, ",".join( [x.uuid for x in result[key] ]   ) ])
                     elif type(result[key]) == list:
                         toptable.append([key, ",".join])
@@ -322,6 +323,9 @@ class RestParser:
         This function will sort list 1 using list 2 values, returning sorted list 1, sorted list 2
         '''
 
+        if len(list1) == 0 or len(list2) == 0:
+            return list1, list2
+
         list1 = list(zip(*sorted(zip(list2,list1))))[1]
         return list1,sorted(list2)
 
@@ -348,7 +352,7 @@ class RestParser:
         projects = Query.GetProjectsUUID(self.nidm_files)
         for uuid in projects:
             result.append(str(uuid).replace(Constants.NIIRI, ""))
-        return self.format(result)
+        return self.format(result, ["UUID"])
 
     def ExpandProjectMetaData(self, meta_data):
         """
@@ -387,8 +391,8 @@ class RestParser:
 
             print(Query.GetParticipantUUIDsForProject(self.nidm_files, project_uuid))
 
-            project['age_max'] = max(ages)
-            project['age_min'] = min(ages)
+            project['age_max'] = max(ages) if len(ages) > 0 else 0
+            project['age_min'] = min(ages) if len(ages) > 0 else 0
             project[Query.matchPrefix(str(Constants.NIDM_NUMBER_OF_SUBJECTS))] = len((Query.GetParticipantUUIDsForProject(self.nidm_files, project_uuid))['uuid'])
             project[str(Constants.NIDM_GENDER)] = list(genders)
             project[str(Constants.NIDM_HANDEDNESS)] = list(hands)
@@ -489,7 +493,7 @@ class RestParser:
         self.restLog("Returing project {} summary".format(id), 2)
 
         result = nidm.experiment.Navigate.GetProjectAttributes(self.nidm_files, project_id=id)
-        result['subjects']  = Query.GetParticipantUUIDsForProject(self.nidm_files, project_id=id, filter=self.query['filter'])
+        result['subjects'] = Query.GetParticipantUUIDsForProject(self.nidm_files, project_id=id, filter=self.query['filter'])
         result['data_elements'] = Query.GetProjectDataElements(self.nidm_files, project_id=id)
 
 
@@ -533,8 +537,9 @@ class RestParser:
 
     def projectSubjectSummary(self):
         match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)/?$", self.command)
+        subject = Navigate.normalizeSingleSubjectToUUID(self.nidm_files, match.group(2))
         self.restLog("Returning info about subject {}".format(match.group(2)), 2)
-        return self.subjectSummaryFormat(Query.GetParticipantDetails(self.nidm_files, match.group(1), match.group(2)))
+        return self.subjectSummaryFormat(Query.GetParticipantDetails(self.nidm_files, match.group(1), subject))
 
     def getFieldInfoForSubject(self, project, subject):
         '''
@@ -567,14 +572,14 @@ class RestParser:
     def subjects(self):
         self.restLog("Returning info about subjects",2)
         projects = Navigate.getProjects(self.nidm_files)
-        result = {'uuid': []}
+        result = {'subject': []}
         if 'fields' in self.query and len(self.query['fields']) > 0:
             result['fields'] = {}
 
         for proj in projects:
             subs = Navigate.getSubjects(self.nidm_files, proj)
             for s in subs:
-                result['uuid'].append(Query.URITail(s))
+                result['subject'].append( [Query.URITail(s), Navigate.getSubjectIDfromUUID(self.nidm_files, s) ])
 
                 # print ("getting info for " + str(s))
                 x = self.getFieldInfoForSubject(proj, s)
@@ -585,13 +590,23 @@ class RestParser:
     def subjectSummary(self):
         match = re.match(r"^/?subjects/([^/]+)/?$", self.command)
         self.restLog("Returning info about subject {}".format(match.group(1)), 2)
-        activities = Navigate.getActivities(self.nidm_files, match.group(1))
+        id = match.group(1)
+
+        # if we were passed in a sub_id rather than a UUID, lookup the associated UUID. (we might get multiple!)
+        if validate_uuid(id):
+            sub_ids = id
+        else:
+            sub_ids = Navigate.getSubjectUUIDsfromID(self.nidm_files, id)
+            if len(sub_ids) == 1:
+                sub_ids = sub_ids[0]
+
+        activities = Navigate.getActivities(self.nidm_files, id)
         activityData = []
         for a in activities:
             data = Navigate.getActivityData(self.nidm_files, a)
             activityData.append(data)
 
-        return self.subjectSummaryFormat_v2( {'uuid': match.group(1),
+        return self.subjectSummaryFormat_v2( {'uuid': sub_ids,
                 'instruments' : list(filter(lambda x: x.category == 'instrument', activityData)),
                 'derivatives' : list(filter(lambda x: x.category == 'derivative', activityData))
                 })
@@ -599,9 +614,10 @@ class RestParser:
 
     def instrumentsList(self):
         result = []
-        match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)$", self.command)
+        match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)/instruments/?$", self.command)
         self.restLog("Returning instruments in subject {}".format(match.group(2)), 2)
-        instruments = Query.GetParticipantInstrumentData(self.nidm_files, match.group(1), match.group(2))
+        subject = Navigate.normalizeSingleSubjectToUUID(self.nidm_files, match.group(2))
+        instruments = Query.GetParticipantInstrumentData(self.nidm_files, match.group(1), subject)
         for i in instruments:
             result.append(i)
         return self.format(result)
@@ -609,23 +625,26 @@ class RestParser:
     def instrumentSummary(self):
         match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)/instruments/([^/]+)$", self.command)
         self.restLog("Returning instrument {} in subject {}".format(match.group(3), match.group(2)), 2)
-        instruments = Query.GetParticipantInstrumentData(self.nidm_files, match.group(1), match.group(2))
+        subject = Navigate.normalizeSingleSubjectToUUID(self.nidm_files, match.group(2))
+        instruments = Query.GetParticipantInstrumentData(self.nidm_files, match.group(1), subject)
         return self.format(instruments[match.group(3)], headers=["Category", "Value"])
 
     def derivativesList(self):
         result = []
         match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)", self.command)
         self.restLog("Returning derivatives in subject {}".format(match.group(2)), 2)
-        derivatives = Query.GetDerivativesDataForSubject(self.nidm_files, match.group(1), match.group(2))
+        subject = Navigate.normalizeSingleSubjectToUUID(self.nidm_files, match.group(2))
+        derivatives = Query.GetDerivativesDataForSubject(self.nidm_files, match.group(1), subject)
         for s in derivatives:
             result.append(s)
         return self.format(result)
 
     def derivativeSummary(self):
         match = re.match(r"^/?projects/([^/]+)/subjects/([^/]+)/derivatives/([^/]+)", self.command)
+        subject = Navigate.normalizeSingleSubjectToUUID(self.nidm_files, match.group(2))
         uri = match.group(3)
         self.restLog("Returning stat {} in subject {}".format(uri, match.group(2)), 2)
-        derivatives = Query.GetDerivativesDataForSubject(self.nidm_files, match.group(1), match.group(2))
+        derivatives = Query.GetDerivativesDataForSubject(self.nidm_files, match.group(1), subject)
 
         single_derivative = { uri: derivatives[uri] }
 
@@ -657,7 +676,8 @@ class RestParser:
                 self.query['fields'] = []
 
             return self.route()
-        except ValueError:
+        except ValueError as ve:
+            logging.error("Exception: {}".format(ve))
             return (self.format({"error": "One of the supplied field terms was not found."}))
 
 
